#pragma once
#include <chrono>
#include <functional>

class TickSystem {
private:
	std::chrono::duration<float> timer{ 0 };
	std::chrono::duration<float> tickRate;

	std::function<void()> callback;
public:
	TickSystem(std::chrono::duration<float> tickRateSeconds, std::function<void()> func)
		: tickRate(tickRateSeconds), callback(func) {
	}

	bool update(std::chrono::duration<float> deltaTime) {
		timer += deltaTime;

		if (timer >= tickRate) {
			timer -= tickRate;
			return true;
		}

		return false;
	}

	void call() const { callback(); }
};
